@@ -3,5 +3,5 @@
 # @Author  : vicissitude
 import timeworker
 
-time_str = '去年13月'
+time_str = '今年'
 print(timeworker.parse(time_str))
\ No newline at end of file
